
*************************************
Mission definitions included in MARXS
*************************************

This section describes mission profiles included in MARXS.
Currently, this is very limited but we expect this to grow in the future and we welcome contributions.

Chandra
=======
MARXS includes a simplified definition for the Chandra X-ray observatory, which includes ACIS and the HETG, but even for those instruments details are missing, e.g. the ACIS contamination and quantum efficiency, and for the HETG the diffraction efficiency. The purpose if this module is a use in examples in this documentation. Please use `classic MARX`_ for any scientific study or Chandra proposal.


Reference/API
=============

.. automodapi:: marxs.missions

.. automodapi:: marxs.missions.chandra
   :skip: HRMA

.. automodapi:: marxs.missions.mitsnl.catgrating
